summaryrefslogtreecommitdiffstats
path: root/kcontrol
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol')
-rw-r--r--kcontrol/access/kaccess.cpp2
-rw-r--r--kcontrol/joystick/caldialog.cpp2
-rw-r--r--kcontrol/joystick/caldialog.h2
-rw-r--r--kcontrol/joystick/joydevice.cpp2
-rw-r--r--kcontrol/joystick/joydevice.h2
-rw-r--r--kcontrol/joystick/joystick.cpp4
-rw-r--r--kcontrol/joystick/joystick.h2
-rw-r--r--kcontrol/joystick/joywidget.cpp2
-rw-r--r--kcontrol/joystick/joywidget.h2
-rw-r--r--kcontrol/joystick/poswidget.cpp2
-rw-r--r--kcontrol/joystick/poswidget.h2
-rw-r--r--kcontrol/kcontrol/main.cpp4
-rw-r--r--kcontrol/keys/keyconfig.cpp2
-rw-r--r--kcontrol/knotify/README2
-rw-r--r--kcontrol/smartcard/nosmartcardbase.ui2
15 files changed, 17 insertions, 17 deletions
diff --git a/kcontrol/access/kaccess.cpp b/kcontrol/access/kaccess.cpp
index 188353d5c..a69c47304 100644
--- a/kcontrol/access/kaccess.cpp
+++ b/kcontrol/access/kaccess.cpp
@@ -748,7 +748,7 @@ void KAccessApp::xkbControlsNotify(XkbControlsNotifyEvent *event)
createDialogContents();
featuresLabel->setText ( question+"\n\n"+explanation
- +" "+i18n("These AccessX settings are needed for some users with motion impairments and can be configured in the KDE Control Center. You can also turn them on and off with standardized keyboard gestures.\n\nIf you do not need them, you can select \"Deactivate all AccessX features and gestures\".") );
+ +" "+i18n("These AccessX settings are needed for some users with motion impairments and can be configured in the TDE Control Center. You can also turn them on and off with standardized keyboard gestures.\n\nIf you do not need them, you can select \"Deactivate all AccessX features and gestures\".") );
KWin::setState( dialog->winId(), NET::KeepAbove );
kapp->updateUserTimestamp();
diff --git a/kcontrol/joystick/caldialog.cpp b/kcontrol/joystick/caldialog.cpp
index 84135bb66..978919caf 100644
--- a/kcontrol/joystick/caldialog.cpp
+++ b/kcontrol/joystick/caldialog.cpp
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/joystick/caldialog.h b/kcontrol/joystick/caldialog.h
index 898b52dd9..343666f97 100644
--- a/kcontrol/joystick/caldialog.h
+++ b/kcontrol/joystick/caldialog.h
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/joystick/joydevice.cpp b/kcontrol/joystick/joydevice.cpp
index 76067ee17..6453bdf6f 100644
--- a/kcontrol/joystick/joydevice.cpp
+++ b/kcontrol/joystick/joydevice.cpp
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/joystick/joydevice.h b/kcontrol/joystick/joydevice.h
index 29d4c49ce..d02d5deea 100644
--- a/kcontrol/joystick/joydevice.h
+++ b/kcontrol/joystick/joydevice.h
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/joystick/joystick.h b/kcontrol/joystick/joystick.h
index bebb8115d..0f412efb3 100644
--- a/kcontrol/joystick/joystick.h
+++ b/kcontrol/joystick/joystick.h
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/joystick/joywidget.cpp b/kcontrol/joystick/joywidget.cpp
index 9a4150678..ae629ac3e 100644
--- a/kcontrol/joystick/joywidget.cpp
+++ b/kcontrol/joystick/joywidget.cpp
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/joystick/joywidget.h b/kcontrol/joystick/joywidget.h
index 47261408d..5a33530f8 100644
--- a/kcontrol/joystick/joywidget.h
+++ b/kcontrol/joystick/joywidget.h
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/joystick/poswidget.cpp b/kcontrol/joystick/poswidget.cpp
index eb24ece23..95fb5dd30 100644
--- a/kcontrol/joystick/poswidget.cpp
+++ b/kcontrol/joystick/poswidget.cpp
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/joystick/poswidget.h b/kcontrol/joystick/poswidget.h
index abe1785c3..4dd565cc5 100644
--- a/kcontrol/joystick/poswidget.h
+++ b/kcontrol/joystick/poswidget.h
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
diff --git a/kcontrol/kcontrol/main.cpp b/kcontrol/kcontrol/main.cpp
index 7a707df21..ded07b006 100644
--- a/kcontrol/kcontrol/main.cpp
+++ b/kcontrol/kcontrol/main.cpp
@@ -103,11 +103,11 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
KLocale::setMainCatalogue("kcontrol");
KAboutData aboutKControl( "kcontrol", I18N_NOOP("Trinity Control Center"),
KCONTROL_VERSION, I18N_NOOP("The Trinity Control Center"), KAboutData::License_GPL,
- I18N_NOOP("(c) 1998-2004, The KDE Control Center Developers"));
+ I18N_NOOP("(c) 1998-2004, The TDE Control Center Developers"));
KAboutData aboutKInfoCenter( "kinfocenter", I18N_NOOP("Trinity Info Center"),
KCONTROL_VERSION, I18N_NOOP("The Trinity Info Center"), KAboutData::License_GPL,
- I18N_NOOP("(c) 1998-2004, The KDE Control Center Developers"));
+ I18N_NOOP("(c) 1998-2004, The TDE Control Center Developers"));
TQCString argv_0 = argv[0];
KAboutData *aboutData;
diff --git a/kcontrol/keys/keyconfig.cpp b/kcontrol/keys/keyconfig.cpp
index 4e35f46a5..a3a0a9e3c 100644
--- a/kcontrol/keys/keyconfig.cpp
+++ b/kcontrol/keys/keyconfig.cpp
@@ -137,7 +137,7 @@ void KKeyModule::init( bool isGlobal, bool _bSeriesOnly, bool bSeriesNone )
// That move will take a lot of UI redesigning, though, so i'll do it once CVS
// opens up for feature commits again. -- ellis
/* Needed to remove because this depended upon non-BC changes in KeyEntry.*/
- // If this is the "Global Keys" section of the KDE Control Center:
+ // If this is the "Global Keys" section of the TDE Control Center:
if( isGlobal && !bSeriesOnly ) {
preferMetaBt = new TQCheckBox( i18n("Prefer 4-modifier defaults"), this );
if( !KKeySequence::keyboardHasMetaKey() )
diff --git a/kcontrol/knotify/README b/kcontrol/knotify/README
index 7fd84d340..712b78d2e 100644
--- a/kcontrol/knotify/README
+++ b/kcontrol/knotify/README
@@ -1,2 +1,2 @@
-This is a KDE Control Center Module for configuring system notifications
+This is a TDE Control Center Module for configuring system notifications
diff --git a/kcontrol/smartcard/nosmartcardbase.ui b/kcontrol/smartcard/nosmartcardbase.ui
index f5f887e5f..bf42f4d49 100644
--- a/kcontrol/smartcard/nosmartcardbase.ui
+++ b/kcontrol/smartcard/nosmartcardbase.ui
@@ -44,7 +44,7 @@
</property>
<property name="text">
<string>
-1) The KDE daemon, 'kded' is not running. You can restart it by running the command 'tdeinit' and then try reloading the KDE Control Center to see if this message goes away.
+1) The KDE daemon, 'kded' is not running. You can restart it by running the command 'tdeinit' and then try reloading the TDE Control Center to see if this message goes away.
2) You don't appear to have smartcard support in the KDE libraries. You will need to recompile the tdelibs package with libpcsclite installed.</string>
</property>
diff --git a/kcontrol/joystick/joystick.cpp b/kcontrol/joystick/joystick.cpp
index 3ffc0e1d7..65912a5a0 100644
--- a/kcontrol/joystick/joystick.cpp
+++ b/kcontrol/joystick/joystick.cpp
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
* This file is part of the KDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
@@ -70,7 +70,7 @@ joystick::joystick(TQWidget *parent, const char *name, const TQStringList &)
: KCModule(JoystickFactory::instance(), parent, name)
{
setAboutData( new KAboutData("kcmjoystick", I18N_NOOP("KDE Joystick Control Module"), "1.0",
- I18N_NOOP("KDE Control Center Module to test Joysticks"),
+ I18N_NOOP("TDE Control Center Module to test Joysticks"),
KAboutData::License_GPL, "(c) 2004, Martin Koller",
0, "m.koller@surfeu.at"));
@@ -1,7 +1,7 @@
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the KDE Control Center Module for Joysticks *
+ * This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *